# coding: utf-8

"""
    GraphQL support

    GraphQL endpoint to query Knowledge Graphs

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from wordlift_client.models.active_account import ActiveAccount
from typing import Optional, Set
from typing_extensions import Self

class PageActiveAccount(BaseModel):
    """
    A page object with links to move to other pages and the list of objects.
    """ # noqa: E501
    first: Optional[StrictStr] = Field(description="The link to the first page.")
    items: List[ActiveAccount] = Field(description="An array of objects.")
    last: Optional[StrictStr] = Field(description="The link to the last page.")
    next: Optional[StrictStr] = Field(description="The link to the next page or `null` if there's no page.")
    prev: Optional[StrictStr] = Field(description="The link to the previous page or `null` if there's no page.")
    var_self: Optional[StrictStr] = Field(description="The link to the current page.", alias="self")
    __properties: ClassVar[List[str]] = ["first", "items", "last", "next", "prev", "self"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PageActiveAccount from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in items (list)
        _items = []
        if self.items:
            for _item in self.items:
                if _item:
                    _items.append(_item.to_dict())
            _dict['items'] = _items
        # set to None if first (nullable) is None
        # and model_fields_set contains the field
        if self.first is None and "first" in self.model_fields_set:
            _dict['first'] = None

        # set to None if last (nullable) is None
        # and model_fields_set contains the field
        if self.last is None and "last" in self.model_fields_set:
            _dict['last'] = None

        # set to None if next (nullable) is None
        # and model_fields_set contains the field
        if self.next is None and "next" in self.model_fields_set:
            _dict['next'] = None

        # set to None if prev (nullable) is None
        # and model_fields_set contains the field
        if self.prev is None and "prev" in self.model_fields_set:
            _dict['prev'] = None

        # set to None if var_self (nullable) is None
        # and model_fields_set contains the field
        if self.var_self is None and "var_self" in self.model_fields_set:
            _dict['self'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PageActiveAccount from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "first": obj.get("first"),
            "items": [ActiveAccount.from_dict(_item) for _item in obj["items"]] if obj.get("items") is not None else None,
            "last": obj.get("last"),
            "next": obj.get("next"),
            "prev": obj.get("prev"),
            "self": obj.get("self")
        })
        return _obj





# coding: utf-8

"""
    GraphQL support

    GraphQL endpoint to query Knowledge Graphs

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.internal_link_request import InternalLinkRequest

class TestInternalLinkRequest(unittest.TestCase):
    """InternalLinkRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InternalLinkRequest:
        """Test InternalLinkRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InternalLinkRequest`
        """
        model = InternalLinkRequest()
        if include_optional:
            return InternalLinkRequest(
                items = [
                    wordlift_client.models.item.Item(
                        query = wordlift_client.models.vector_search_query_request.VectorSearchQueryRequest(
                            fields = [
                                ''
                                ], 
                            filters = [
                                wordlift_client.models.filter.Filter(
                                    key = '', 
                                    operator = 'EQ', 
                                    value = wordlift_client.models.filter_value.Filter_value(), )
                                ], 
                            query_embedding = [
                                1.337
                                ], 
                            query_string = '', 
                            query_uri = '', 
                            query_url = '', 
                            similarity_top_k = 1, ), 
                        source_name = '', )
                    ],
                template = ''
            )
        else:
            return InternalLinkRequest(
        )
        """

    def testInternalLinkRequest(self):
        """Test InternalLinkRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.page_active_account import PageActiveAccount

class TestPageActiveAccount(unittest.TestCase):
    """PageActiveAccount unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PageActiveAccount:
        """Test PageActiveAccount
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PageActiveAccount`
        """
        model = PageActiveAccount()
        if include_optional:
            return PageActiveAccount(
                first = '',
                items = [
                    wordlift_client.models.active_account.ActiveAccount(
                        country = '', 
                        diagnostic_plugins = [
                            wordlift_client.models.diagnostic_plugin.DiagnosticPlugin(
                                account_id = 56, 
                                active = True, 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                id = 56, 
                                name = '', 
                                version = '', )
                            ], 
                        domain_uri = '', 
                        google_search_console_site_url = '', 
                        id = 56, 
                        is_wordpress = True, 
                        key = '', 
                        language = '', 
                        ng_dataset_id = '', 
                        package_type = '', 
                        subscription = wordlift_client.models.account_subscription.AccountSubscription(
                            email = '', 
                            first_name = '', 
                            last_name = '', 
                            order_id = 56, 
                            sku = '', ), 
                        subscription_id = 56, 
                        total_entities = 56, 
                        total_entities_with_schema_url = 56, 
                        url = '', 
                        user_id = 56, 
                        wp_admin = '', 
                        wp_include_exclude_default = '', 
                        wp_json = '', )
                    ],
                last = '',
                next = '',
                prev = '',
                var_self = ''
            )
        else:
            return PageActiveAccount(
                first = '',
                items = [
                    wordlift_client.models.active_account.ActiveAccount(
                        country = '', 
                        diagnostic_plugins = [
                            wordlift_client.models.diagnostic_plugin.DiagnosticPlugin(
                                account_id = 56, 
                                active = True, 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                id = 56, 
                                name = '', 
                                version = '', )
                            ], 
                        domain_uri = '', 
                        google_search_console_site_url = '', 
                        id = 56, 
                        is_wordpress = True, 
                        key = '', 
                        language = '', 
                        ng_dataset_id = '', 
                        package_type = '', 
                        subscription = wordlift_client.models.account_subscription.AccountSubscription(
                            email = '', 
                            first_name = '', 
                            last_name = '', 
                            order_id = 56, 
                            sku = '', ), 
                        subscription_id = 56, 
                        total_entities = 56, 
                        total_entities_with_schema_url = 56, 
                        url = '', 
                        user_id = 56, 
                        wp_admin = '', 
                        wp_include_exclude_default = '', 
                        wp_json = '', )
                    ],
                last = '',
                next = '',
                prev = '',
                var_self = '',
        )
        """

    def testPageActiveAccount(self):
        """Test PageActiveAccount"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Middleware

    Knowledge Graph data management.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.get_entities200_response import GetEntities200Response

class TestGetEntities200Response(unittest.TestCase):
    """GetEntities200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetEntities200Response:
        """Test GetEntities200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetEntities200Response`
        """
        model = GetEntities200Response()
        if include_optional:
            return GetEntities200Response(
            )
        else:
            return GetEntities200Response(
        )
        """

    def testGetEntities200Response(self):
        """Test GetEntities200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SEO Content Analysis API

    This API assesses the match between a URL or text content, a query, and an intent, using advanced SEO techniques.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.account_stats import AccountStats

class TestAccountStats(unittest.TestCase):
    """AccountStats unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AccountStats:
        """Test AccountStats
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AccountStats`
        """
        model = AccountStats()
        if include_optional:
            return AccountStats(
                entities_with_url = 56,
                product_groups = 56,
                products = 56
            )
        else:
            return AccountStats(
                entities_with_url = 56,
                product_groups = 56,
                products = 56,
        )
        """

    def testAccountStats(self):
        """Test AccountStats"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.smart_content_request import SmartContentRequest

class TestSmartContentRequest(unittest.TestCase):
    """SmartContentRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SmartContentRequest:
        """Test SmartContentRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SmartContentRequest`
        """
        model = SmartContentRequest()
        if include_optional:
            return SmartContentRequest(
                account_id = 1,
                model_id = 1,
                rules = [
                    wordlift_client.models.rule_request.RuleRequest(
                        description = '', 
                        fixes = [
                            wordlift_client.models.validation_fix.ValidationFix(
                                type = 'FIND_AND_REPLACE', 
                                what = '', 
                                with = '', )
                            ], 
                        is_enabled = True, 
                        level = 'RECOMMENDED', 
                        name = '', 
                        project_id = 56, 
                        project_type = 'SMART_CONTENT', 
                        scope = 'USER', 
                        type = '', 
                        what_operand_lhs = 'EVERYWHERE', 
                        what_operand_rhs = '', 
                        what_operator = 'CONTAINS', 
                        when_operand_lhs = '', 
                        when_operand_rhs = '', 
                        when_operator = 'ALWAYS', )
                    ],
                webpage_properties = [
                    wordlift_client.models.webpage_properties.WebpageProperties(
                        entities = [
                            ''
                            ], 
                        iri = '', 
                        query = '', 
                        url = '', )
                    ]
            )
        else:
            return SmartContentRequest(
                account_id = 1,
        )
        """

    def testSmartContentRequest(self):
        """Test SmartContentRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    GraphQL support

    GraphQL endpoint to query Knowledge Graphs

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.internal_link import InternalLink

class TestInternalLink(unittest.TestCase):
    """InternalLink unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InternalLink:
        """Test InternalLink
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InternalLink`
        """
        model = InternalLink()
        if include_optional:
            return InternalLink(
                destinations = [
                    wordlift_client.models.internal_link_destination.InternalLinkDestination(
                        name = '', 
                        position = 56, 
                        url = '', )
                    ],
                source = wordlift_client.models.internal_link_source.InternalLinkSource(
                    id = '', 
                    name = '', 
                    url = '', )
            )
        else:
            return InternalLink(
                destinations = [
                    wordlift_client.models.internal_link_destination.InternalLinkDestination(
                        name = '', 
                        position = 56, 
                        url = '', )
                    ],
                source = wordlift_client.models.internal_link_source.InternalLinkSource(
                    id = '', 
                    name = '', 
                    url = '', ),
        )
        """

    def testInternalLink(self):
        """Test InternalLink"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.account_subscription import AccountSubscription

class TestAccountSubscription(unittest.TestCase):
    """AccountSubscription unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AccountSubscription:
        """Test AccountSubscription
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AccountSubscription`
        """
        model = AccountSubscription()
        if include_optional:
            return AccountSubscription(
                email = '',
                first_name = '',
                last_name = '',
                order_id = 56,
                sku = ''
            )
        else:
            return AccountSubscription(
        )
        """

    def testAccountSubscription(self):
        """Test AccountSubscription"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
